# Model Feature Scan Report

_Report generated on: 2025-06-07T13:23:32.942467_

## API: GeminiApi

### API Summary

* **Total Models Scanned:** 47
* **Average Supported Features per Model:** 3.74

#### Feature Support Across Models:

* Audio: 59.6% (28/47)
* AudioConversion: 0.0% (0/47)
* AudioEmbeddings: 0.0% (0/47)
* AudioGeneration: 0.0% (0/47)
* AudioTranscription: 2.1% (1/47)
* Document: 0.0% (0/47)
* DocumentConversion: 0.0% (0/47)
* DocumentEmbeddings: 0.0% (0/47)
* Image: 66.0% (31/47)
* ImageConversion: 0.0% (0/47)
* ImageEmbeddings: 0.0% (0/47)
* ImageGeneration: 0.0% (0/47)
* StructuredTextGeneration: 55.3% (26/47)
* TextEmbeddings: 6.4% (3/47)
* TextGeneration: 66.0% (31/47)
* Thinking: 0.0% (0/47)
* Tools: 53.2% (25/47)
* Video: 66.0% (31/47)
* VideoConversion: 0.0% (0/47)
* VideoEmbeddings: 0.0% (0/47)
* VideoGeneration: 0.0% (0/47)

### Model Details

#### Model: fastembed (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-001 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-001-tuning (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-002 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-8b (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-8b-001 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-8b-exp-0827 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-8b-exp-0924 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-8b-latest (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-flash-latest (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-pro (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-pro-001 (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-pro-002 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-1.5-pro-latest (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-001 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-exp (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-exp-image-generation (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-lite (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-lite-001 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-lite-preview (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-lite-preview-02-05 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-preview-image-generation (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-thinking-exp (5/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-thinking-exp-01-21 (5/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-flash-thinking-exp-1219 (5/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-pro-exp (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.0-pro-exp-02-05 (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-exp-native-audio-thinking-dialog (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-preview-04-17 (5/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-preview-04-17-thinking (5/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-preview-05-20 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-preview-native-audio-dialog (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-preview-native-audio-dialog-rai-v3 (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-flash-preview-tts (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-pro-exp-03-25 (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-pro-preview-03-25 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-pro-preview-05-06 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-pro-preview-06-05 (6/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ✅ Audio
* ✅ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-2.5-pro-preview-tts (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-embedding-exp (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-embedding-exp-03-07 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/gemini-exp-1206 (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/imagen-3.0-generate-002 (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: models/text-embedding-004 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: whisper-local (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ✅ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

_This report is auto-generated by Litemind. Some features may not be supported due to model limitations, API
restrictions, or potential bugs in Litemind._